from setuptools import setup

setup(name='dsndls_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dsndls_distributions'],
      author = 'Liberto Siahaan',
      author_mail = 'liberto.siahaan@gmail.com',
      zip_safe=False)
